### Persephone - a socio-economic-ecological model of European agricultural landscapes.
###
### These are the tests for the core simulation functions.
###

@testset "Model initialisation" begin
    model = initialise(TESTPARAMETERS)
    @test typeof(model.settings) == Dict{String, Dict{String, Any}}
    @test model.date == Date(2022,2,1)
    @test typeof(model.landscape) == Matrix{Pixel}
    @test typeof(model.dataoutputs) == Vector{DataOutput}
    @test length(model.dataoutputs) == 2
    @test model.events == Vector{FarmEvent}()
    @test nagents(model) == 2092+10+28
end

@testset "Model simulation" begin
    Random.seed!(1)
    @test isapprox(rand(), 0.07337, atol=0.0001)
    model = simulate(TESTPARAMETERS, 218)
    @test @param(core.seed) == 218
    @test model.date == Date(2022,4,1)
    nwol = sum((typeof(a)==Animal && a.traits["name"]=="Wolpertinger") for a in allagents(model))
    nwyv = sum((typeof(a)==Animal && a.traits["name"]=="Wyvern") for a in allagents(model))
    #FIXME these still fail - although it might not be that clever to rely on random model outcomes
    @test nwol == 32
    @test nwyv == 9
    # To retain reproducibility, the model code must never use the global RNG.
    # If this next test fails, that requirement has probably been violated somewhere.
    #FIXME it does fail... Might it be called by some dependency?
    @test isapprox(rand(), 0.34924, atol=0.0001)
end
 
